<?php

class Webexpert_Social_Bar_Watermark {

	protected $loader;
	protected $plugin_name;
	protected $version;

	public function __construct() {
		if ( defined( 'PLUGIN_NAME_VERSION' ) ) {
			$this->version = PLUGIN_NAME_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'webexpert-social-bar-watermark';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	private function load_dependencies() {
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-webexpert-social-bar-watermark-loader.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-webexpert-social-bar-watermark-i18n.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-webexpert-social-bar-watermark-admin.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-webexpert-social-bar-watermark-public.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/acf/acf.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/acf/settings.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/Image-master/src/Bedeabza/Image.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/Image-master/src/Bedeabza/Image/Exception.php';
		$this->loader = new Webexpert_Social_Bar_Watermark_Loader();
	}

	private function set_locale() {
		$plugin_i18n = new Webexpert_Social_Bar_Watermark_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
        $this->loader->add_filter( 'acf/settings/l10n', $plugin_i18n, 'acf_settings_localization' );
        $this->loader->add_filter( 'acf/settings/l10n_textdomain', $plugin_i18n, 'acf_settings_textdomain' );

	}

	private function define_admin_hooks() {
		$plugin_admin = new Webexpert_Social_Bar_Watermark_Admin( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
        $this->loader->add_action('init', $plugin_admin,'register_options_page');
        $this->loader->add_filter('acf/settings/show_admin', $plugin_admin,'webexpert__return_false');
        $this->loader->add_filter('admin_post_thumbnail_html', $plugin_admin,'add_featured_image_display_settings', 10, 2 );
	}

	private function define_public_hooks() {
		$plugin_public = new Webexpert_Social_Bar_Watermark_Public( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
        $this->loader->add_filter( 'query_vars', $plugin_public, 'socialbar_image_rewrite_add_var' );
        $this->loader->add_action('init', $plugin_public, 'add_socialbar_image_rewrite_add_var_rewrite_rule');
        $this->loader->add_action( 'template_redirect', $plugin_public, 'socialbar_image_rewrite_catch');
        $this->loader->add_action( 'wp_head', $plugin_public, 'add_socialbar_og_tag',1);
        $this->loader->add_filter('wpseo_opengraph_image' ,$plugin_public, 'webexpert__return_false' );
		$this->loader->add_action( 'wp_ajax_regenerate_socialbar', $plugin_public, 'regenerate_socialbar' );
		$this->loader->add_action( 'wp_ajax_nopriv_regenerate_socialbar', $plugin_public, 'regenerate_socialbar' );
		$this->loader->add_action( 'publish_post', $plugin_public, 'regenerate_socialbar_upon_publish', 10, 2 );
	}

	public function run() {
		$this->loader->run();
	}

	public function get_plugin_name() {
		return $this->plugin_name;
	}

	public function get_loader() {
		return $this->loader;
	}

	public function get_version() {
		return $this->version;
	}
}