<?php

use \Bedeabza\Image;

class Webexpert_Social_Bar_Watermark_Public {

	private $plugin_name;
	private $version;
    private $nWidth;
    private $nHeight;

	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
        $this->nWidth=get_field('image_width','option');
        $this->nHeight=get_field('image_height','option');
	}

	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/webexpert-social-bar-watermark-public.css', array(), $this->version, 'all' );
	}

	public function enqueue_scripts() {
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/webexpert-social-bar-watermark-public.js', array( 'jquery' ), $this->version, false );
	}

    public function socialbar_image_rewrite_add_var( $vars )
    {
        $vars[] = 'socialbar';
        return $vars;
    }
    public function add_socialbar_image_rewrite_add_var_rewrite_rule(){
        add_rewrite_tag( '%socialbar%', '([^&]+)' );
        add_rewrite_rule(
            '^socialbar/([^/]*)/?',
            'index.php?socialbar=$matches[1]',
            'top'
        );
    }
    public function socialbar_image_rewrite_catch($post_id=null)
    {
        global $wp_query;

        if ( array_key_exists( 'socialbar', $wp_query->query_vars ) || $post_id ) {
            $get_id=get_query_var('socialbar');
            if (!$post_id) {
                $id=sanitize_text_field(intval($get_id));
            }else {
                $id=$post_id;
            }
            $image_url = wp_get_attachment_image_src( get_post_thumbnail_id($id), 'full');

            if ($image_url){
                $domain = get_site_url();
                $uploads = wp_upload_dir();
                $filename = $uploads['basedir']."/webexpert-social-watermark/posts/$id.jpg";

                $logo_path=str_replace($uploads['baseurl'], $uploads['basedir'],get_field('logo','option'));
                $file_path = str_replace( $uploads['baseurl'], $uploads['basedir'], $image_url[0] );

                $image = new Image($file_path);
                $image->resize($this->nWidth, $this->nHeight);

                $im = imagecreatetruecolor($this->nWidth, get_field('bar_height','option'));
                imagealphablending($im, false);
                imagesavealpha($im,true);
                $hex = get_field('colour','option');

                list($r, $g, $b) = sscanf($hex, "#%02x%02x%02x");
                $transparent = imagecolorallocatealpha($im, $r, $g, $b, get_field('transparency','option'));
                imagefilledrectangle($im, 0, 0, $this->nWidth, get_field('bar_height','option'), $transparent);
                imagepng($im, $uploads['basedir']."/webexpert-social-watermark/imagefilledrectangle.png");

                $image->watermark($uploads['basedir']."/webexpert-social-watermark/imagefilledrectangle.png",Image::WM_POS_BOTTOM_RIGHT);
                $image->watermark($logo_path,Image::WM_POS_BOTTOM_RIGHT,20,20);
                $image->save($filename, 80);

                return true;
            }else {
                global $wp_query;
                $wp_query->set_404();
                status_header(404);
                return false;
            }
        }
    }

    public function add_socialbar_og_tag() {
        if (is_singular('post') && (has_post_thumbnail(get_the_ID()))) {
            $upload_dir = wp_upload_dir();
            $filename = $upload_dir['baseurl'].'/webexpert-social-watermark/posts/'.get_the_ID().'.jpg';
            $filename_dir = $upload_dir['basedir'].'/webexpert-social-watermark/posts/'.get_the_ID().'.jpg';
            if (!file_exists($filename_dir)) {
                echo self::socialbar_image_rewrite_catch(get_the_ID());
            }

echo '<meta property="og:image" content="'.$filename.'">
<meta property="og:image:width" content="'.$this->nWidth.'"/>
<meta property="og:image:height" content="'.$this->nHeight  .'"/>
';
        }
    }

    public function regenerate_socialbar() {
       if ( !wp_verify_nonce( $_REQUEST['nonce'], "regenerate_socialbar")) {
          exit("No naughty business please");
       }
       $post_id=sanitize_text_field($_REQUEST['post_id']);
       if (Webexpert_Social_Bar_Watermark_Public::socialbar_image_rewrite_catch($post_id)) {
            $result = json_encode(array('success'=>1));
       }else{
            $result = json_encode(array('success'=>0));
       }
       echo $result;
       die();
    }

    function regenerate_socialbar_upon_publish( $ID, $post ) {
        $upload_dir = wp_upload_dir();
        $filename_dir = $upload_dir['basedir'].'/webexpert-social-watermark/posts/'.$ID.'.jpg';
        if (!file_exists($filename_dir)) {
            echo self::socialbar_image_rewrite_catch($ID);
        }
    }

    function webexpert__return_false() {
        return false;
    }
}