<?php
/*
Plugin Name: Web Expert Social Bar Watermark
Plugin URI:  https://www.webexpert.gr/wordpress/social-bar-watermark
Description: Creates a dynamic bar with your logo on every featured image shared by your website to Facebook
Version: 1.0.4
Author: Web Expert
Author URI: http://www.webexpert.gr
License: Web Expert license
Text Domain: webexpert-social-bar-watermark
*/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

require plugin_dir_path( __FILE__ ).'includes/update/plugin-update-checker.php';
$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
    'https://www.webexpert.gr/plugins/updates/?action=get_metadata&slug=webexpert-social-bar-watermark',
    __FILE__,
    'webexpert-social-bar-watermark'
);
//Add the license key to query arguments.
$myUpdateChecker->addQueryArgFilter('webexpert_social_bar_watermark_update_checks');
function webexpert_social_bar_watermark_update_checks($queryArgs) {
    $license = get_option('we_social_bar_watermark_license_key');
    $domain = get_bloginfo('url');
    $parse = parse_url($domain);
    $domain = $parse['scheme'].'://'.$parse['host'];
    if ( !empty($license) ) {
        $queryArgs['license_key'] = $license;
    }
    if ( !empty($domain) ) {
        $queryArgs['domain'] = $domain;
    }
    return $queryArgs;
}

add_action('admin_menu', 'webexpert_social_bar_watermark_options_page');
function webexpert_social_bar_watermark_options_page()
{
    if ( empty ( $GLOBALS['admin_page_hooks']['webexpert_plugins'] ) )
        add_menu_page('Web Expert Plugins','Web Expert','manage_options','webexpert_plugins','webexpert_social_bar_watermark_settings_main_menu',null,20);
    add_submenu_page('webexpert_plugins',__( 'Socialbar Watermark', 'webexpert-social-bar-watermark' ), __( 'Socialbar Watermark', 'webexpert-social-bar-watermark' ),'manage_options','webexpert_plugins-social-bar-watermark','webexpert_social_bar_watermark_options_page_html'    );
    remove_submenu_page('webexpert_plugins','webexpert_plugins');
}
add_action( 'admin_init', 'webexpert_social_bar_watermark_settings' );
function webexpert_social_bar_watermark_settings() {
	//register our settings
	register_setting( 'webexpert_social_bar_watermark_settings-group', 'we_social_bar_watermark_email' );
	register_setting( 'webexpert_social_bar_watermark_settings-group', 'we_social_bar_watermark_license_key' );
}
function webexpert_social_bar_watermark_settings_main_menu() {
    if (!current_user_can('manage_options')) {
        return;
    }
    ?>
    <div class="wrap">
    <h1><?= esc_html(get_admin_page_title()); ?></h1>
    <p>Ευχαριστούμε που επιλέγε την Web Expert.</p>
    </div>
    <?php
}


function webexpert_social_bar_watermark_options_page_html()
{
    if (!current_user_can('manage_options')) {
        return;
    }
    ?>
    <div class="wrap">
        <h1><?= esc_html(get_admin_page_title()); ?></h1>
        <p>Παρακαλώ προσθέστε το κλειδί που λάβατε κατά την αγορά του Social Bar Watermark ώστε να λαμβάνετε αυτόματα ενημερώσεις ασφαλείας και να εξασφαλίσετε την ομαλή λειτουργία του πρόσθετου.</p>
        <form action="options.php" method="post">
            <?php
            settings_fields('webexpert_social_bar_watermark_settings-group');
            do_settings_sections('webexpert_social_bar_watermark_settings-group');
            ?>
    <table class="form-table">
        <tr valign="top">
        <th scope="row">Email</th>
        <td><input type="text" name="we_social_bar_watermark_email" value="<?php echo esc_attr( get_option('we_social_bar_watermark_email') ); ?>" /></td>
        </tr>

        <tr valign="top">
        <th scope="row">License Key</th>
        <td><input type="text" name="we_social_bar_watermark_license_key" value="<?php echo esc_attr( get_option('we_social_bar_watermark_license_key') ); ?>" /></td>
        </tr>
    </table>
    <?php submit_button();  ?>
        <input type="hidden" name="" value="<?php echo $_SERVER['HTTP_HOST'];?>">
        </form>
    </div>
    <?php
}

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-webexpert-social-bar-watermark-activator.php
 */
function activate_webexpert_social_bar_watermark() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-webexpert-social-bar-watermark-activator.php';
	Webexpert_Social_Bar_Watermark_Activator::activate();

}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-webexpert-social-bar-watermark-deactivator.php
 */
function deactivate_webexpert_social_bar_watermark() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-webexpert-social-bar-watermark-deactivator.php';
	Webexpert_Social_Bar_Watermark_Deactivator::deactivate();
    flush_rewrite_rules();
}

register_activation_hook( __FILE__, 'activate_webexpert_social_bar_watermark' );
register_deactivation_hook( __FILE__, 'deactivate_webexpert_social_bar_watermark' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-webexpert-social-bar-watermark.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_webexpert_social_bar_watermark() {

	$plugin = new Webexpert_Social_Bar_Watermark();
	$plugin->run();

}
run_webexpert_social_bar_watermark();
